@@ -1,20 +1,12 @@
 from pydantic import BaseModel as _BaseModel
-import datetime
 from abc import ABC as _ABC, abstractmethod as _abstractmethod
 from typing import Any
+import datetime
 
 from .relation import Relation
 
 
 class Schema(_BaseModel, _ABC):
-    def serializable(self, types: tuple[type, ...] = (datetime.datetime, datetime.date, datetime.time)) -> dict[str: Any]:
-        """
-        Returns python dictionary of values which will not trigger FastAPI error related to not serializable objects
-        :param types:
-        :return:
-        """
-        return {key: str(value) if isinstance(value, types) else value for key, value in dict(self).items()}
-
     @property
     @_abstractmethod
     def __tablename__(self) -> str:
@@ -35,10 +27,17 @@ class Schema(_BaseModel, _ABC):
     def relations(self) -> list[Relation]:
         return []
 
-    def pretty(self) -> 'Schema':
+    def serializable(self, types: tuple[type, ...] = (datetime.datetime, datetime.date, datetime.time)) -> dict[str: Any]:
         """
-        Assign prettified values to Schema.properties.
-        For instance: self.email = self.email.lower(); self.surname = self.surname.capitalize; return self;
+        Returns python dictionary of values which will not trigger FastAPI error related to not serializable objects
+        :param types:
         :return:
         """
+        return {key: str(value) if isinstance(value, types) else value for key, value in dict(self).items()}
+
+    def into_db(self) -> 'Schema':
         return self
+
+    def from_db(self) -> 'Schema':
+        return self
+
