@@ -1,4 +1,4 @@
-from apidevtools import Schema, Relation
+from apidevtools import Schema
 
 
 class ItemBase(Schema):
